# eyantra-autoeval

## Usage

> NOTE: Check [#3][i3] for generating result from the evaluator.

- For `Sentinel Drone` theme

  ```sh
  eyantra-autoeval evaluate --year 2022 --theme SD --task 0
  ```

- For `Luminosity Drone` theme

  ```sh
  eyantra-autoeval evaluate --year 2023 --theme LD --task 0
  ```

- For `AstroTinker Bot` theme

  ```sh
  eyantra-autoeval evaluate --year 2023 --theme AB --task 0     # Task 0
  eyantra-autoeval evaluate --year 2023 --theme AB --task 2A    # Task 2A
  ```

- For `Cosmo Logistic` theme

  ```sh
  eyantra-autoeval evaluate --year 2023 --theme CL --task 0     # Task 0
  eyantra-autoeval evaluate --year 2023 --theme CL --task 1A    # Task 1A
  eyantra-autoeval evaluate --year 2023 --theme CL --task 1B    # Task 1B
  eyantra-autoeval evaluate --year 2023 --theme CL --task 1C    # Task 1C
  eyantra-autoeval evaluate --year 2023 --theme CL --task 2A    # Task 2A
  eyantra-autoeval evaluate --year 2023 --theme CL --task 2B    # Task 2B
  ```

- For `Holyglyph Bots` theme

  ```sh
  eyantra-autoeval evaluate --year 2023 --theme HB --task 0
  ```

[i3]: https://github.com/eYantra-Robotics-Competition/eyantra-autoeval/issues/3
